#ifndef INCLUDED_NEWREGEX
#define INCLUDED_NEWREGEX

#if defined (_WIN32) && !defined (USE_GNUREGEX)
# define USE_GNUREGEX 1
#endif
#ifdef USE_GNUREGEX
# include "GNUregex.h"
#elif HAVE_REGEX_H
# include <regex.h>
#endif
#ifdef HAVE_GLOB_H
# include <glob.h>
#endif

#endif
